@@ -25,12 +25,12 @@ import unittest
 
 import SCons.Errors
 import SCons.Node.Python
+from SCons.Script import Depends
 
 
 class ValueTestCase(unittest.TestCase):
-    def test_Value(self):
-        """Test creating a Value() object
-        """
+    def test_Value(self) -> None:
+        """Test creating a Value() object."""
         v1 = SCons.Node.Python.Value('a')
         assert v1.value == 'a', v1.value
 
@@ -39,45 +39,50 @@ class ValueTestCase(unittest.TestCase):
         assert v2.value == value2, v2.value
         assert v2.value is value2, v2.value
 
+        # the two nodes are not the same though they have same attributes
         assert v1 is not v2
         assert v1.value == v2.value
+        assert v1.name == v2.name
 
+        # node takes the built_value if one is supplied.
         v3 = SCons.Node.Python.Value('c', 'cb')
         assert v3.built_value == 'cb'
 
-    def test_build(self):
-        """Test "building" a Value Node
-        """
+    def test_build(self) -> None:
+        """Test "building" a Value Node."""
         class fake_executor:
-            def __call__(self, node):
+            def __call__(self, node) -> None:
                 node.write('faked')
 
-        v1 = SCons.Node.Python.Value('b', 'built')
+        # *built_value* arg means already built, executor will not be called
+        v1 = SCons.Node.Python.Value('b', built_value='built')
         v1.executor = fake_executor()
         v1.build()
         assert v1.built_value == 'built', v1.built_value
 
+        # not built, executor will build it
         v2 = SCons.Node.Python.Value('b')
         v2.executor = fake_executor()
         v2.build()
         assert v2.built_value == 'faked', v2.built_value
 
+        # test the *name* parameter to refer to the node
         v3 = SCons.Node.Python.Value(b'\x00\x0F', name='name')
         v3.executor = fake_executor()
         v3.build()
-        assert v3.name == 'name', v3.name
         assert v3.built_value == 'faked', v3.built_value
+        # building the node does not change the name
+        assert v3.name == 'name', v3.name
 
-    def test_read(self):
-        """Test the Value.read() method
-        """
+    def test_read(self) -> None:
+        """Test the Value.read() method."""
         v1 = SCons.Node.Python.Value('a')
         x = v1.read()
         assert x == 'a', x
 
-    def test_write(self):
-        """Test the Value.write() method
-        """
+    def test_write(self) -> None:
+        """Test the Value.write() method."""
+        # creating the node without built_value does not set it
         v1 = SCons.Node.Python.Value('a')
         assert v1.value == 'a', v1.value
         assert not hasattr(v1, 'built_value')
@@ -86,9 +91,8 @@ class ValueTestCase(unittest.TestCase):
         assert v1.value == 'a', v1.value
         assert v1.built_value == 'new', v1.built_value
 
-    def test_get_csig(self):
-        """Test calculating the content signature of a Value() object
-        """
+    def test_get_csig(self) -> None:
+        """Test calculating the content signature of a Value() object."""
         v1 = SCons.Node.Python.Value('aaa')
         csig = v1.get_csig(None)
         assert csig == 'aaa', csig
@@ -101,26 +105,35 @@ class ValueTestCase(unittest.TestCase):
         csig = v3.get_csig(None)
         assert csig == 'None', csig
 
-
-
+        # Dependencies: a tree of Value nodes comes back as a single string.
+        # This may change someday, bot for now:
+        v1 = SCons.Node.Python.Value('node1')
+        v2 = SCons.Node.Python.Value('node2')
+        v3 = SCons.Node.Python.Value('node3')
+        v4 = SCons.Node.Python.Value('node4')
+        Depends(v1, [v2, v3])
+        Depends(v3, v4)
+        assert v1.read() == 'node1', v1.read
+        csig = v1.get_csig()
+        assert csig == 'node1node2node3node4', csig
 
 
 class ValueNodeInfoTestCase(unittest.TestCase):
-    def test___init__(self):
+    def test___init__(self) -> None:
         """Test ValueNodeInfo initialization"""
         vvv = SCons.Node.Python.Value('vvv')
         ni = SCons.Node.Python.ValueNodeInfo()
 
 
 class ValueBuildInfoTestCase(unittest.TestCase):
-    def test___init__(self):
+    def test___init__(self) -> None:
         """Test ValueBuildInfo initialization"""
         vvv = SCons.Node.Python.Value('vvv')
         bi = SCons.Node.Python.ValueBuildInfo()
 
 
 class ValueChildTestCase(unittest.TestCase):
-    def test___init__(self):
+    def test___init__(self) -> None:
         """Test support for a Value() being an implicit dependency of a Node"""
         value = SCons.Node.Python.Value('v')
         node = SCons.Node.Node()
@@ -132,7 +145,7 @@ class ValueChildTestCase(unittest.TestCase):
 
 
 class ValueMemoTestCase(unittest.TestCase):
-    def test_memo(self):
+    def test_memo(self) -> None:
         """Test memoization"""
         # First confirm that ValueWithMemo does memoization.
         value1 = SCons.Node.Python.ValueWithMemo('vvv')
@@ -145,13 +158,13 @@ class ValueMemoTestCase(unittest.TestCase):
         value3 = ni.str_to_node('vvv')
         assert value1 is value3
 
-    def test_built_value(self):
+    def test_built_value(self) -> None:
         """Confirm that built values are not memoized."""
         v1 = SCons.Node.Python.ValueWithMemo('c', 'ca')
         v2 = SCons.Node.Python.ValueWithMemo('c', 'ca')
         assert v1 is not v2
 
-    def test_non_primitive_values(self):
+    def test_non_primitive_values(self) -> None:
         """Confirm that non-primitive values are not memoized."""
         d = {'a': 1}
         v1 = SCons.Node.Python.ValueWithMemo(d)
@@ -163,7 +176,7 @@ class ValueMemoTestCase(unittest.TestCase):
         v4 = SCons.Node.Python.ValueWithMemo(a)
         assert v3 is not v4
 
-    def test_value_set_name(self):
+    def test_value_set_name(self) -> None:
         """ Confirm setting name and caching takes the name into account """
 
         v1 = SCons.Node.Python.ValueWithMemo(b'\x00\x0F', name='name')
