@@ -1,11 +1,6 @@
-"""SCons.Platform.mingw
-
-Platform-specific initialization for the MinGW system.
-
-"""
-
+# MIT License
 #
-# __COPYRIGHT__
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,9 +20,8 @@ Platform-specific initialization for the MinGW system.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
+"""Platform-specific initialization for the MinGW system."""
 
 import sys
 
@@ -35,5 +29,7 @@ MINGW_DEFAULT_PATHS = []
 if sys.platform == 'win32':
     MINGW_DEFAULT_PATHS = [
         r'C:\msys64',
-        r'C:\msys'
-    ]
\ No newline at end of file
+        r'C:\msys64\usr\bin',
+        r'C:\msys',
+        r'C:\msys\usr\bin'
+    ]
