@@ -58,7 +58,7 @@ if False:
 
         shutil.copy2 = CopyFile
 
-        def win_api_copyfile(src,dst):
+        def win_api_copyfile(src,dst) -> None:
             CopyFile(src,dst)
             os.utime(dst)
 
@@ -81,9 +81,8 @@ try:
     # This locked version of spawnve works around a Windows
     # MSVCRT bug, because its spawnve is not thread-safe.
     # Without this, python can randomly crash while using -jN.
-    # See the python bug at http://bugs.python.org/issue6476
-    # and SCons issue at
-    # https://github.com/SCons/scons/issues/2449
+    # See the python bug at https://github.com/python/cpython/issues/50725
+    # and SCons issue at https://github.com/SCons/scons/issues/2449
     def spawnve(mode, file, args, env):
         spawn_lock.acquire()
         try:
@@ -166,18 +165,20 @@ def piped_spawn(sh, escape, cmd, args, env, stdout, stderr):
     # and do clean up stuff
     if stdout is not None and not stdoutRedirected:
         try:
-            with open(tmpFileStdoutName, "r") as tmpFileStdout:
-                stdout.write(tmpFileStdout.read())
+            with open(tmpFileStdoutName, "rb") as tmpFileStdout:
+                output = tmpFileStdout.read()
+                stdout.write(output.decode('oem', "replace").replace("\r\n", "\n"))
             os.remove(tmpFileStdoutName)
-        except (IOError, OSError):
+        except OSError:
             pass
 
     if stderr is not None and not stderrRedirected:
         try:
-            with open(tmpFileStderrName, "r") as tmpFileStderr:
-                stderr.write(tmpFileStderr.read())
+            with open(tmpFileStderrName, "rb") as tmpFileStderr:
+                errors = tmpFileStderr.read()
+                stderr.write(errors.decode('oem', "replace").replace("\r\n", "\n"))
             os.remove(tmpFileStderrName)
-        except (IOError, OSError):
+        except OSError:
             pass
 
     return ret
@@ -186,7 +187,7 @@ def piped_spawn(sh, escape, cmd, args, env, stdout, stderr):
 def exec_spawn(l, env):
     try:
         result = spawnve(os.P_WAIT, l[0], l, env)
-    except (OSError, EnvironmentError) as e:
+    except OSError as e:
         try:
             result = exitvalmap[e.errno]
             sys.stderr.write("scons: %s: %s\n" % (l[0], e.strerror))
@@ -283,7 +284,7 @@ class ArchDefinition:
     Determine which windows CPU were running on.
     A class for defining architecture-specific settings and logic.
     """
-    def __init__(self, arch, synonyms=[]):
+    def __init__(self, arch, synonyms=[]) -> None:
         self.arch = arch
         self.synonyms = synonyms
 
@@ -298,6 +299,11 @@ SupportedArchitectureList = [
         ['AMD64', 'amd64', 'em64t', 'EM64T', 'x86_64'],
     ),
 
+    ArchDefinition(
+        'arm64',
+        ['ARM64', 'aarch64', 'AARCH64', 'AArch64'],
+    ),
+
     ArchDefinition(
         'ia64',
         ['IA64'],
@@ -315,9 +321,20 @@ def get_architecture(arch=None):
     """Returns the definition for the specified architecture string.
 
     If no string is specified, the system default is returned (as defined
-    by the PROCESSOR_ARCHITEW6432 or PROCESSOR_ARCHITECTURE environment
-    variables).
+    by the registry PROCESSOR_ARCHITECTURE value, PROCESSOR_ARCHITEW6432
+    environment variable, PROCESSOR_ARCHITECTURE environment variable, or
+    the platform machine).
     """
+    if arch is None:
+        if SCons.Util.can_read_reg:
+            try:
+                k=SCons.Util.RegOpenKeyEx(SCons.Util.hkey_mod.HKEY_LOCAL_MACHINE,
+                                          'SYSTEM\\CurrentControlSet\\Control\\Session Manager\\Environment')
+                val, tok = SCons.Util.RegQueryValueEx(k, 'PROCESSOR_ARCHITECTURE')
+            except SCons.Util.RegError:
+                val = ''
+            if val and val in SupportedArchitectureMap:
+                arch = val
     if arch is None:
         arch = os.environ.get('PROCESSOR_ARCHITEW6432')
         if not arch:
@@ -405,8 +422,9 @@ def generate(env):
     env['LIBSUFFIX']      = '.lib'
     env['SHLIBPREFIX']    = ''
     env['SHLIBSUFFIX']    = '.dll'
-    env['LIBPREFIXES']    = [ '$LIBPREFIX' ]
-    env['LIBSUFFIXES']    = [ '$LIBSUFFIX' ]
+    env['LIBPREFIXES']    = ['$LIBPREFIX']
+    env['LIBSUFFIXES']    = ['$LIBSUFFIX']
+    env['LIBLITERALPREFIX'] = ''
     env['PSPAWN']         = piped_spawn
     env['SPAWN']          = spawn
     env['SHELL']          = cmd_interp
