@@ -81,7 +81,7 @@ test.write('incNO.tex', "\n")
 # define some helpers:
 #   copied from CTest.py
 class DummyEnvironment(collections.UserDict):
-    def __init__(self, **kw):
+    def __init__(self, **kw) -> None:
         super().__init__()
         self.data.update(kw)
         self.fs = SCons.Node.FS.FS(test.workpath(''))
@@ -121,7 +121,7 @@ if os.path.normcase('foo') == os.path.normcase('FOO'):
 else:
     my_normpath = os.path.normpath
 
-def deps_match(self, deps, headers):
+def deps_match(self, deps, headers) -> None:
     global my_normpath
     scanned = list(map(my_normpath, list(map(str, deps))))
     expect = list(map(my_normpath, headers))
@@ -129,7 +129,7 @@ def deps_match(self, deps, headers):
 
 
 class LaTeXScannerTestCase1(unittest.TestCase):
-    def runTest(self):
+    def runTest(self) -> None:
         env = DummyEnvironment(LATEXSUFFIXES = [".tex", ".ltx", ".latex"])
         s = SCons.Scanner.LaTeX.LaTeXScanner()
         path = s.path(env)
@@ -141,7 +141,7 @@ class LaTeXScannerTestCase1(unittest.TestCase):
         deps_match(self, deps, headers)
 
 class LaTeXScannerTestCase2(unittest.TestCase):
-     def runTest(self):
+     def runTest(self) -> None:
          env = DummyEnvironment(TEXINPUTS=[test.workpath("subdir")],LATEXSUFFIXES = [".tex", ".ltx", ".latex"])
          s = SCons.Scanner.LaTeX.LaTeXScanner()
          path = s.path(env)
@@ -150,7 +150,7 @@ class LaTeXScannerTestCase2(unittest.TestCase):
          deps_match(self, deps, headers)
 
 class LaTeXScannerTestCase3(unittest.TestCase):
-     def runTest(self):
+     def runTest(self) -> None:
          env = DummyEnvironment(TEXINPUTS=[test.workpath("subdir")],LATEXSUFFIXES = [".tex", ".ltx", ".latex"])
          s = SCons.Scanner.LaTeX.LaTeXScanner()
          path = s.path(env)
@@ -159,7 +159,7 @@ class LaTeXScannerTestCase3(unittest.TestCase):
          deps_match(self, deps, files)
 
 class LaTeXScannerTestCase4(unittest.TestCase):
-     def runTest(self):
+     def runTest(self) -> None:
          env = DummyEnvironment(TEXINPUTS=[test.workpath("subdir")],LATEXSUFFIXES = [".tex", ".ltx", ".latex"])
          s = SCons.Scanner.LaTeX.LaTeXScanner()
          path = s.path(env)
