@@ -63,37 +63,37 @@ num_tasks = num_jobs*5
 
 class DummyLock:
     """fake lock class to use if threads are not supported"""
-    def acquire(self):
+    def acquire(self) -> None:
         pass
 
-    def release(self):
+    def release(self) -> None:
         pass
 
 class NoThreadsException(Exception):
     """raised by the ParallelTestCase if threads are not supported"""
 
-    def __str__(self):
+    def __str__(self) -> str:
         return "the interpreter doesn't support threads"
 
 class Task:
     """A dummy task class for testing purposes."""
 
-    def __init__(self, i, taskmaster):
+    def __init__(self, i, taskmaster) -> None:
         self.i = i
         self.taskmaster = taskmaster
         self.was_executed = 0
         self.was_prepared = 0
 
-    def prepare(self):
+    def prepare(self) -> None:
         self.was_prepared = 1
 
-    def _do_something(self):
+    def _do_something(self) -> None:
         pass
 
-    def needs_execute(self):
+    def needs_execute(self) -> bool:
         return True
 
-    def execute(self):
+    def execute(self) -> None:
         self.taskmaster.test_case.assertTrue(self.was_prepared,
                                   "the task wasn't prepared")
 
@@ -119,7 +119,7 @@ class Task:
         self.taskmaster.end_list.append(self.i)
         self.taskmaster.guard.release()
 
-    def executed(self):
+    def executed(self) -> None:
         self.taskmaster.num_executed = self.taskmaster.num_executed + 1
 
         self.taskmaster.test_case.assertTrue(self.was_prepared,
@@ -129,20 +129,20 @@ class Task:
         self.taskmaster.test_case.assertTrue(isinstance(self, Task),
                                   "the task wasn't really a Task instance")
 
-    def failed(self):
+    def failed(self) -> None:
         self.taskmaster.num_failed = self.taskmaster.num_failed + 1
         self.taskmaster.stop = 1
         self.taskmaster.test_case.assertTrue(self.was_prepared,
                                   "the task wasn't prepared")
 
-    def postprocess(self):
+    def postprocess(self) -> None:
         self.taskmaster.num_postprocessed = self.taskmaster.num_postprocessed + 1
 
-    def exception_set(self):
+    def exception_set(self) -> None:
         pass
 
 class RandomTask(Task):
-    def _do_something(self):
+    def _do_something(self) -> None:
         # do something that will take some random amount of time:
         for i in range(random.randrange(0, 100 + num_sines, 1)):
             x = math.sin(i)
@@ -151,20 +151,20 @@ class RandomTask(Task):
 class ExceptionTask:
     """A dummy task class for testing purposes."""
 
-    def __init__(self, i, taskmaster):
+    def __init__(self, i, taskmaster) -> None:
         self.taskmaster = taskmaster
         self.was_prepared = 0
 
-    def prepare(self):
+    def prepare(self) -> None:
         self.was_prepared = 1
 
-    def needs_execute(self):
+    def needs_execute(self) -> bool:
         return True
 
     def execute(self):
         raise Exception
 
-    def executed(self):
+    def executed(self) -> None:
         self.taskmaster.num_executed = self.taskmaster.num_executed + 1
 
         self.taskmaster.test_case.assertTrue(self.was_prepared,
@@ -174,22 +174,22 @@ class ExceptionTask:
         self.taskmaster.test_case.assertTrue(self.__class__ is Task,
                                   "the task wasn't really a Task instance")
 
-    def failed(self):
+    def failed(self) -> None:
         self.taskmaster.num_failed = self.taskmaster.num_failed + 1
         self.taskmaster.stop = 1
         self.taskmaster.test_case.assertTrue(self.was_prepared,
                                   "the task wasn't prepared")
 
-    def postprocess(self):
+    def postprocess(self) -> None:
         self.taskmaster.num_postprocessed = self.taskmaster.num_postprocessed + 1
 
-    def exception_set(self):
+    def exception_set(self) -> None:
         self.taskmaster.exception_set()
 
 class Taskmaster:
     """A dummy taskmaster class for testing the job classes."""
 
-    def __init__(self, n, test_case, Task):
+    def __init__(self, n, test_case, Task) -> None:
         """n is the number of dummy tasks to perform."""
 
         self.test_case = test_case
@@ -202,6 +202,7 @@ class Taskmaster:
         self.parallel_list = [0] * (n+1)
         self.found_parallel = False
         self.Task = Task
+        self.trace = False
 
         # 'guard' guards 'task_begin_list' and 'task_end_list'
         try:
@@ -232,14 +233,14 @@ class Taskmaster:
     def all_tasks_are_postprocessed(self):
         return self.num_postprocessed == self.num_tasks
 
-    def tasks_were_serial(self):
+    def tasks_were_serial(self) -> bool:
         """analyze the task order to see if they were serial"""
         return not self.found_parallel
 
-    def exception_set(self):
+    def exception_set(self) -> None:
         pass
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         pass
 
 
@@ -292,7 +293,7 @@ class ParallelTestCase(JobTestCase):
         # tasks complete and get their notifications on the resultsQueue.
 
         class SleepTask(Task):
-            def _do_something(self):
+            def _do_something(self) -> None:
                 time.sleep(0.01)
 
         global SaveThreadPool
@@ -312,7 +313,9 @@ class ParallelTestCase(JobTestCase):
 
         try:
             taskmaster = Taskmaster(3, self, SleepTask)
+            OptionsParser.values.experimental.append('legacy_sched')
             jobs = SCons.Taskmaster.Job.Jobs(2, taskmaster)
+            OptionsParser.values.experimental.pop()
             jobs.run()
 
             # The key here is that we get(1) and get(2) from the
@@ -329,7 +332,7 @@ class ParallelTestCase(JobTestCase):
             SCons.Taskmaster.Job.ThreadPool = SaveThreadPool
 
 class SerialTestCase(unittest.TestCase):
-    def runTest(self):
+    def runTest(self) -> None:
         """test a serial job"""
 
         taskmaster = Taskmaster(num_tasks, self, RandomTask)
@@ -348,36 +351,8 @@ class SerialTestCase(unittest.TestCase):
                     "some task(s) failed to execute")
 
 
-class NoParallelTestCase(JobTestCase):
-
-    def runTest(self):
-        """test handling lack of parallel support"""
-        def NoParallel(tm, num, stack_size):
-            raise NameError
-        save_Parallel = SCons.Taskmaster.Job.LegacyParallel
-        SCons.Taskmaster.Job.LegacyParallel = NoParallel
-        try:
-            taskmaster = Taskmaster(num_tasks, self, RandomTask)
-            jobs = SCons.Taskmaster.Job.Jobs(2, taskmaster)
-            self.assertTrue(jobs.num_jobs == 1,
-                            "unexpected number of jobs %d" % jobs.num_jobs)
-            jobs.run()
-            self.assertTrue(taskmaster.tasks_were_serial(),
-                            "the tasks were not executed in series")
-            self.assertTrue(taskmaster.all_tasks_are_executed(),
-                            "all the tests were not executed")
-            self.assertTrue(taskmaster.all_tasks_are_iterated(),
-                            "all the tests were not iterated over")
-            self.assertTrue(taskmaster.all_tasks_are_postprocessed(),
-                            "all the tests were not postprocessed")
-            self.assertFalse(taskmaster.num_failed,
-                        "some task(s) failed to execute")
-        finally:
-            SCons.Taskmaster.Job.LegacyParallel = save_Parallel
-
-
 class SerialExceptionTestCase(unittest.TestCase):
-    def runTest(self):
+    def runTest(self) -> None:
         """test a serial job with tasks that raise exceptions"""
 
         taskmaster = Taskmaster(num_tasks, self, ExceptionTask)
@@ -396,7 +371,7 @@ class SerialExceptionTestCase(unittest.TestCase):
 
 class ParallelExceptionTestCase(JobTestCase):
 
-    def runTest(self):
+    def runTest(self) -> None:
         """test parallel jobs with tasks that raise exceptions"""
 
         taskmaster = Taskmaster(num_tasks, self, ExceptionTask)
@@ -421,23 +396,23 @@ import SCons.Node
 import time
 
 class DummyNodeInfo:
-    def update(self, obj):
+    def update(self, obj) -> None:
         pass
 
 class testnode (SCons.Node.Node):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.expect_to_be = SCons.Node.executed
         self.ninfo = DummyNodeInfo()
 
 class goodnode (testnode):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.expect_to_be = SCons.Node.up_to_date
         self.ninfo = DummyNodeInfo()
 
 class slowgoodnode (goodnode):
-    def prepare(self):
+    def prepare(self) -> None:
         # Delay to allow scheduled Jobs to run while the dispatcher
         # sleeps.  Keep this short because it affects the time taken
         # by this test.
@@ -445,7 +420,7 @@ class slowgoodnode (goodnode):
         goodnode.prepare(self)
 
 class badnode (goodnode):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.expect_to_be = SCons.Node.failed
     def build(self, **kw):
@@ -467,7 +442,7 @@ class badpreparenode (badnode):
 
 class _SConsTaskTest(JobTestCase):
 
-    def _test_seq(self, num_jobs):
+    def _test_seq(self, num_jobs) -> None:
         for node_seq in [
             [goodnode],
             [badnode],
@@ -484,7 +459,7 @@ class _SConsTaskTest(JobTestCase):
 
             self._do_test(num_jobs, node_seq)
 
-    def _do_test(self, num_jobs, node_seq):
+    def _do_test(self, num_jobs, node_seq) -> None:
 
         testnodes = []
         for tnum in range(num_tasks):
@@ -549,18 +524,21 @@ class _SConsTaskTest(JobTestCase):
 
 
 class SerialTaskTest(_SConsTaskTest):
-    def runTest(self):
+    def runTest(self) -> None:
         """test serial jobs with actual Taskmaster and Task"""
         self._test_seq(1)
 
+        # Now run test with LegacyParallel
+        OptionsParser.values.experimental=['legacy_sched']
+        self._test_seq(1)
 
 class ParallelTaskTest(_SConsTaskTest):
-    def runTest(self):
+    def runTest(self) -> None:
         """test parallel jobs with actual Taskmaster and Task"""
         self._test_seq(num_jobs)
 
-        # Now run test with NewParallel() instead of LegacyParallel
-        OptionsParser.values.experimental=['tm_v2']
+        # Now run test with LegacyParallel
+        OptionsParser.values.experimental=['legacy_sched']
         self._test_seq(num_jobs)
 
 
