@@ -1,14 +1,6 @@
-"""SCons.Tool.install
-
-Tool-specific initialization for the install tool.
-
-There normally shouldn't be any need to import this module directly.
-It will usually be imported through the generic SCons.Tool.Tool()
-selection method.
-"""
-
+# MIT License
 #
-# __COPYRIGHT__
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -28,17 +20,28 @@ selection method.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
+
+""" Tool-specific initialization for the install tool.
+
+There normally shouldn't be any need to import this module directly.
+It will usually be imported through the generic SCons.Tool.Tool()
+selection method.
+"""
 
 import os
-from shutil import copy2, copymode, copystat
+import stat
+from shutil import copy2, copystat
 
 import SCons.Action
 import SCons.Tool
 import SCons.Util
+from SCons.Subst import SUBST_RAW
+from SCons.Tool.linkCommon import (
+    StringizeLibSymlinks,
+    CreateLibSymlinks,
+    EmitLibSymlinks,
+)
 
-#
 # We keep track of *all* installed files.
 _INSTALLED_FILES = []
 _UNIQUE_INSTALLED_FILES = None
@@ -47,8 +50,8 @@ class CopytreeError(OSError):
     pass
 
 
-def scons_copytree(src, dst, symlinks=False, ignore=None, copy_function=copy2,
-                   ignore_dangling_symlinks=False, dirs_exist_ok=False):
+def scons_copytree(src, dst, symlinks: bool=False, ignore=None, copy_function=copy2,
+                   ignore_dangling_symlinks: bool=False, dirs_exist_ok: bool=False):
     """Recursively copy a directory tree, SCons version.
 
     This is a modified copy of the Python 3.7 shutil.copytree function.
@@ -119,12 +122,17 @@ def scons_copytree(src, dst, symlinks=False, ignore=None, copy_function=copy2,
                         continue
                     # otherwise let the copy occurs. copy2 will raise an error
                     if os.path.isdir(srcname):
-                        scons_copytree(srcname, dstname, symlinks, ignore,
-                                       copy_function, dirs_exist_ok)
+                        scons_copytree(srcname, dstname, symlinks=symlinks,
+                                       ignore=ignore, copy_function=copy_function,
+                                       ignore_dangling_symlinks=ignore_dangling_symlinks,
+                                       dirs_exist_ok=dirs_exist_ok)
                     else:
                         copy_function(srcname, dstname)
             elif os.path.isdir(srcname):
-                scons_copytree(srcname, dstname, symlinks, ignore, copy_function, dirs_exist_ok)
+                scons_copytree(srcname, dstname, symlinks=symlinks,
+                               ignore=ignore, copy_function=copy_function,
+                               ignore_dangling_symlinks=ignore_dangling_symlinks,
+                               dirs_exist_ok=dirs_exist_ok)
             else:
                 # Will raise a SpecialFileError for unsupported file types
                 copy_function(srcname, dstname)
@@ -147,11 +155,14 @@ def scons_copytree(src, dst, symlinks=False, ignore=None, copy_function=copy2,
 #
 # Functions doing the actual work of the Install Builder.
 #
-def copyFunc(dest, source, env):
-    """Install a source file or directory into a destination by copying,
+def copyFunc(dest, source, env) -> int:
+    """Install a source file or directory into a destination by copying.
 
-    Mode/permissions bits will be copied as well.
+    Mode/permissions bits will be copied as well, except that the target
+    will be made writable.
 
+    Returns:
+        POSIX-style error code - 0 for success, non-zero for fail
     """
     if os.path.isdir(source):
         if os.path.exists(dest):
@@ -164,19 +175,24 @@ def copyFunc(dest, source, env):
         scons_copytree(source, dest, dirs_exist_ok=True)
     else:
         copy2(source, dest)
-        copymode(source, dest)
+        st = os.stat(source)
+        os.chmod(dest, stat.S_IMODE(st[stat.ST_MODE]) | stat.S_IWRITE)
 
     return 0
 
 #
 # Functions doing the actual work of the InstallVersionedLib Builder.
 #
-def copyFuncVersionedLib(dest, source, env):
-    """Install a versioned library into a destination by copying,
+def copyFuncVersionedLib(dest, source, env) -> int:
+    """Install a versioned library into a destination by copying.
 
-    Mode/permissions bits will be copied as well.
     Any required symbolic links for other library names are created.
 
+    Mode/permissions bits will be copied as well, except that the target
+    will be made writable.
+
+    Returns:
+        POSIX-style error code - 0 for success, non-zero for fail
     """
     if os.path.isdir(source):
         raise SCons.Errors.UserError("cannot install directory `%s' as a version library" % str(source) )
@@ -187,7 +203,8 @@ def copyFuncVersionedLib(dest, source, env):
         except:
             pass
         copy2(source, dest)
-        copymode(source, dest)
+        st = os.stat(source)
+        os.chmod(dest, stat.S_IMODE(st[stat.ST_MODE]) | stat.S_IWRITE)
         installShlibLinks(dest, source, env)
 
     return 0
@@ -208,48 +225,68 @@ def listShlibLinksToInstall(dest, source, env):
                 install_links.append((install_link, install_linktgt))
     return install_links
 
-def installShlibLinks(dest, source, env):
+def installShlibLinks(dest, source, env) -> None:
     """If we are installing a versioned shared library create the required links."""
     Verbose = False
     symlinks = listShlibLinksToInstall(dest, source, env)
     if Verbose:
-        print('installShlibLinks: symlinks={!r}'.format(SCons.Tool.StringizeLibSymlinks(symlinks)))
+        print(f'installShlibLinks: symlinks={StringizeLibSymlinks(symlinks)!r}')
     if symlinks:
-        SCons.Tool.CreateLibSymlinks(env, symlinks)
+        CreateLibSymlinks(env, symlinks)
     return
 
-def installFunc(target, source, env):
-    """Install a source file into a target using the function specified
-    as the INSTALL construction variable."""
+def installFunc(target, source, env) -> int:
+    """Install a source file into a target.
+
+    Uses the function specified in the INSTALL construction variable.
+
+    Returns:
+        POSIX-style error code - 0 for success, non-zero for fail
+    """
+
     try:
         install = env['INSTALL']
     except KeyError:
         raise SCons.Errors.UserError('Missing INSTALL construction variable.')
 
-    assert len(target)==len(source), \
-           "Installing source %s into target %s: target and source lists must have same length."%(list(map(str, source)), list(map(str, target)))
-    for t,s in zip(target,source):
-        if install(t.get_path(),s.get_path(),env):
+    assert len(target) == len(source), (
+        "Installing source %s into target %s: "
+        "target and source lists must have same length."
+        % (list(map(str, source)), list(map(str, target)))
+    )
+    for t, s in zip(target, source):
+        if install(t.get_path(), s.get_path(), env):
             return 1
 
     return 0
 
-def installFuncVersionedLib(target, source, env):
-    """Install a versioned library into a target using the function specified
-    as the INSTALLVERSIONEDLIB construction variable."""
+def installFuncVersionedLib(target, source, env) -> int:
+    """Install a versioned library into a target.
+
+    Uses the function specified in the INSTALL construction variable.
+
+    Returns:
+        POSIX-style error code - 0 for success, non-zero for fail
+    """
+
     try:
         install = env['INSTALLVERSIONEDLIB']
     except KeyError:
-        raise SCons.Errors.UserError('Missing INSTALLVERSIONEDLIB construction variable.')
+        raise SCons.Errors.UserError(
+            'Missing INSTALLVERSIONEDLIB construction variable.'
+        )
 
-    assert len(target)==len(source), \
-           "Installing source %s into target %s: target and source lists must have same length."%(list(map(str, source)), list(map(str, target)))
-    for t,s in zip(target,source):
+    assert len(target) == len(source), (
+        "Installing source %s into target %s: "
+        "target and source lists must have same length."
+        % (list(map(str, source)), list(map(str, target)))
+    )
+    for t, s in zip(target, source):
         if hasattr(t.attributes, 'shlibname'):
             tpath = os.path.join(t.get_dir(), t.attributes.shlibname)
         else:
             tpath = t.get_path()
-        if install(tpath,s.get_path(),env):
+        if install(tpath, s.get_path(), env):
             return 1
 
     return 0
@@ -257,7 +294,7 @@ def installFuncVersionedLib(target, source, env):
 def stringFunc(target, source, env):
     installstr = env.get('INSTALLSTR')
     if installstr:
-        return env.subst_target_source(installstr, 0, target, source)
+        return env.subst_target_source(installstr, SUBST_RAW, target, source)
     target = str(target[0])
     source = str(source[0])
     if os.path.isdir(source):
@@ -289,10 +326,10 @@ def add_versioned_targets_to_INSTALLED_FILES(target, source, env):
     Verbose = False
     _INSTALLED_FILES.extend(target)
     if Verbose:
-        print("add_versioned_targets_to_INSTALLED_FILES: target={!r}".format(list(map(str, target))))
+        print(f"add_versioned_targets_to_INSTALLED_FILES: target={list(map(str, target))!r}")
     symlinks = listShlibLinksToInstall(target[0], source, env)
     if symlinks:
-        SCons.Tool.EmitLibSymlinks(env, symlinks, target[0])
+        EmitLibSymlinks(env, symlinks, target[0])
     _UNIQUE_INSTALLED_FILES = None
     return (target, source)
 
@@ -300,7 +337,7 @@ class DESTDIR_factory:
     """ A node factory, where all files will be relative to the dir supplied
     in the constructor.
     """
-    def __init__(self, env, dir):
+    def __init__(self, env, dir) -> None:
         self.env = env
         self.dir = env.arg2nodes( dir, env.fs.Dir )[0]
 
@@ -392,7 +429,7 @@ def InstallVersionedBuilderWrapper(env, target=None, source=None, dir=None, **kw
 added = None
 
 
-def generate(env):
+def generate(env) -> None:
 
     from SCons.Script import AddOption, GetOption
     global added
@@ -416,9 +453,9 @@ def generate(env):
                               action         = install_action,
                               target_factory = target_factory.Entry,
                               source_factory = env.fs.Entry,
-                              multi          = 1,
+                              multi          = True,
                               emitter        = [ add_targets_to_INSTALLED_FILES, ],
-                              source_scanner = SCons.Scanner.Base( {}, name = 'Install', recursive = False ),
+                              source_scanner = SCons.Scanner.ScannerBase({}, name='Install', recursive=False),
                               name           = 'InstallBuilder')
 
     global BaseVersionedInstallBuilder
@@ -433,7 +470,7 @@ def generate(env):
                                        action         = installVerLib_action,
                                        target_factory = target_factory.Entry,
                                        source_factory = env.fs.Entry,
-                                       multi          = 1,
+                                       multi          = True,
                                        emitter        = [ add_versioned_targets_to_INSTALLED_FILES, ],
                                        name           = 'InstallVersionedBuilder')
 
@@ -456,15 +493,15 @@ def generate(env):
     try:
         env['INSTALL']
     except KeyError:
-        env['INSTALL']    = copyFunc
+        env['INSTALL'] = copyFunc
 
     try:
         env['INSTALLVERSIONEDLIB']
     except KeyError:
-        env['INSTALLVERSIONEDLIB']    = copyFuncVersionedLib
+        env['INSTALLVERSIONEDLIB'] = copyFuncVersionedLib
 
-def exists(env):
-    return 1
+def exists(env) -> bool:
+    return True
 
 # Local Variables:
 # tab-width:4
