@@ -6,53 +6,50 @@
 
 The SCons test suite consists of:
 
- * unit tests        - *Tests.py files from the SCons/ dir
+ * unit tests        - *Tests.py files from the SCons/ directory
  * end-to-end tests  - *.py files in the test/ directory that
-                       require the custom SCons framework from testing/
+                       require the custom SCons framework from
+                       testing/framework.
 
 This script adds SCons/ and testing/ directories to PYTHONPATH,
 performs test discovery and processes tests according to options.
 """
 
-# TODO: normalize requested and testlist/exclude paths for easier comparison.
-# e.g.: "runtest foo/bar" on windows will produce paths like foo/bar\test.py
-# this is hard to match with excludelists, and makes those both os.sep-specific
-# and command-line-typing specific.
-
 import argparse
-import glob
+import itertools
 import os
-import stat
 import subprocess
 import sys
 import tempfile
 import threading
 import time
 from abc import ABC, abstractmethod
-from pathlib import Path
+from io import StringIO
+from pathlib import Path, PurePath, PureWindowsPath
 from queue import Queue
+from typing import List, TextIO, Optional
 
 cwd = os.getcwd()
-
-debug = None
-scons = None
-catch_output = False
-suppress_output = False
-
-script = os.path.basename(sys.argv[0])
-usagestr = """\
-%(script)s [OPTIONS] [TEST ...]
-""" % locals()
-
+debug: Optional[str] = None
+scons: Optional[str] = None
+catch_output: bool = False
+suppress_output: bool = False
+script = PurePath(sys.argv[0]).name
+usagestr = f"{script} [OPTIONS] [TEST ...]"
 epilogstr = """\
 Environment Variables:
   PRESERVE, PRESERVE_{PASS,FAIL,NO_RESULT}: preserve test subdirs
   TESTCMD_VERBOSE: turn on verbosity in TestCommand\
 """
 
+# this is currently expected to be global, maybe refactor later?
+unittests: List[str]
+
 parser = argparse.ArgumentParser(
-    usage=usagestr, epilog=epilogstr, allow_abbrev=False,
-    formatter_class=argparse.RawDescriptionHelpFormatter
+    usage=usagestr,
+    epilog=epilogstr,
+    allow_abbrev=False,
+    formatter_class=argparse.RawDescriptionHelpFormatter,
 )
 
 # test selection options:
@@ -83,7 +80,15 @@ parser.add_argument('-D', '--devmode', action='store_true',
                     help="Run tests in Python's development mode (Py3.7+ only).")
 parser.add_argument('-e', '--external', action='store_true',
                     help="Run the script in external mode (for external Tools)")
-parser.add_argument('-j', '--jobs', metavar='JOBS', default=1, type=int,
+
+def posint(arg: str) -> int:
+    """Special positive-int type for argparse"""
+    num = int(arg)
+    if num < 0:
+        raise argparse.ArgumentTypeError("JOBS value must not be negative")
+    return num
+
+parser.add_argument('-j', '--jobs', metavar='JOBS', default=1, type=posint,
                     help="Run tests in JOBS parallel jobs (0 for cpu_count).")
 parser.add_argument('-l', '--list', action='store_true', dest='list_only',
                     help="List available tests and exit.")
@@ -130,7 +135,7 @@ outctl.add_argument('-q', '--quiet', action='store_false',
                     help="Don't print the test being executed.")
 outctl.add_argument('-s', '--short-progress', action='store_true',
                     help="""Short progress, prints only the command line
-                             and a progress percentage.""")
+                             and a progress percentage, no results.""")
 outctl.add_argument('-t', '--time', action='store_true', dest='print_times',
                     help="Print test execution time.")
 outctl.add_argument('--verbose', metavar='LEVEL', type=int, choices=range(1, 4),
@@ -139,14 +144,18 @@ outctl.add_argument('--verbose', metavar='LEVEL', type=int, choices=range(1, 4),
                              2=print commands and non-zero output,
                              3=print commands and all output).""")
 # maybe add?
-# outctl.add_argument('--version', action='version', version='%s 1.0' % script)
+# outctl.add_argument('--version', action='version', version=f'{script} 1.0')
 
 logctl = parser.add_argument_group(description='Log control options:')
 logctl.add_argument('-o', '--output', metavar='LOG', help="Save console output to LOG.")
-logctl.add_argument('--xml', metavar='XML', help="Save results to XML in SCons XML format.")
+logctl.add_argument(
+    '--xml',
+    metavar='XML',
+    help="Save results to XML in SCons XML format (use - for stdout).",
+)
 
 # process args and handle a few specific cases:
-args = parser.parse_args()
+args: argparse.Namespace = parser.parse_args()
 
 # we can't do this check with an argparse exclusive group, since those
 # only work with optional args, and the cmdline tests (args.testlist)
@@ -164,38 +173,30 @@ if args.retry:
 if args.testlistfile:
     # args.testlistfile changes from a string to a pathlib Path object
     try:
-        p = Path(args.testlistfile)
-        # TODO simplify when Py3.5 dropped
-        if sys.version_info.major == 3 and sys.version_info.minor < 6:
-            args.testlistfile = p.resolve()
-        else:
-            args.testlistfile = p.resolve(strict=True)
+        ptest = Path(args.testlistfile)
+        args.testlistfile = ptest.resolve(strict=True)
     except FileNotFoundError:
         sys.stderr.write(
             parser.format_usage()
-            + 'error: -f/--file testlist file "%s" not found\n' % p
+            + f'error: -f/--file testlist file "{args.testlistfile}" not found\n'
         )
         sys.exit(1)
 
 if args.excludelistfile:
     # args.excludelistfile changes from a string to a pathlib Path object
     try:
-        p = Path(args.excludelistfile)
-        # TODO simplify when Py3.5 dropped
-        if sys.version_info.major == 3 and sys.version_info.minor < 6:
-            args.excludelistfile = p.resolve()
-        else:
-            args.excludelistfile = p.resolve(strict=True)
+        pexcl = Path(args.excludelistfile)
+        args.excludelistfile = pexcl.resolve(strict=True)
     except FileNotFoundError:
         sys.stderr.write(
             parser.format_usage()
-            + 'error: --exclude-list file "%s" not found\n' % p
+            + f'error: --exclude-list file "{args.excludelistfile}" not found\n'
         )
         sys.exit(1)
 
 if args.jobs == 0:
     try:
-        # on Linux, check available rather then physical CPUs
+        # on Linux, check available rather than physical CPUs
         args.jobs = len(os.sched_getaffinity(0))
     except AttributeError:
         # Windows
@@ -293,6 +294,7 @@ if sys.platform == 'win32':
     E_POINTER = ctypes.c_long(0x80004003).value
 
     def get_template_command(filetype, verb=None):
+        """Return the association-related string for *filetype*"""
         flags = ASSOCF_INIT_IGNOREUNKNOWN | ASSOCF_NOTRUNCATE
         assoc_str = ASSOCSTR_COMMAND
         cch = ctypes.c_ulong(260)
@@ -388,11 +390,13 @@ else:
 
 class RuntestBase(ABC):
     """ Base class for tests """
-    def __init__(self, path, num, spe=None):
-        self.path = path
-        self.num = num
+    _ids = itertools.count(1)  # to geenerate test # automatically
+
+    def __init__(self, path, spe=None):
+        self.path = str(path)
+        self.testno = next(self._ids)
         self.stdout = self.stderr = self.status = None
-        self.abspath = os.path.abspath(path)
+        self.abspath = path.absolute()
         self.command_args = []
         self.command_str = ""
         self.test_time = self.total_time = 0
@@ -404,7 +408,7 @@ class RuntestBase(ABC):
                     break
 
     @abstractmethod
-    def execute(self):
+    def execute(self, env):
         pass
 
 
@@ -413,7 +417,7 @@ class SystemExecutor(RuntestBase):
     def execute(self, env):
         self.stderr, self.stdout, s = spawn_it(self.command_args, env)
         self.status = s
-        if s < 0 or s > 2:
+        if s < 0 or s > 2 and s != 5:
             sys.stdout.write("Unexpected exit status %d\n" % s)
 
 
@@ -430,7 +434,7 @@ class PopenExecutor(RuntestBase):
     # definition of spawn_it() above.
     if args.allow_pipe_files:
 
-        def execute(self, env):
+        def execute(self, env) -> None:
             # Create temporary files
             tmp_stdout = tempfile.TemporaryFile(mode='w+t')
             tmp_stderr = tempfile.TemporaryFile(mode='w+t')
@@ -441,6 +445,7 @@ class PopenExecutor(RuntestBase):
                 stderr=tmp_stderr,
                 shell=False,
                 env=env,
+                check=False,
             )
             self.status = cp.returncode
 
@@ -457,13 +462,14 @@ class PopenExecutor(RuntestBase):
                 tmp_stderr.close()
     else:
 
-        def execute(self, env):
+        def execute(self, env) -> None:
             cp = subprocess.run(
                 self.command_args,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
                 shell=False,
                 env=env,
+                check=False,
             )
             self.status, self.stdout, self.stderr = cp.returncode, cp.stdout, cp.stderr
 
@@ -497,7 +503,11 @@ else:
 if not args.baseline or args.baseline == '.':
     baseline = cwd
 elif args.baseline == '-':
-    print("This logic used to checkout from svn. It's been removed. If you used this, please let us know on devel mailing list, IRC, or discord server")
+    sys.stderr.write(
+        "'baseline' logic used to checkout from svn. It has been removed. "
+        "If you used this, please let us know on devel mailing list, "
+        "IRC, or discord server\n"
+    )
     sys.exit(-1)
 else:
     baseline = args.baseline
@@ -547,7 +557,7 @@ if sys.platform == 'win32':
     # Windows doesn't support "shebang" lines directly (the Python launcher
     # and Windows Store version do, but you have to get them launched first)
     # so to directly launch a script we depend on an assoc for .py to work.
-    # Some systems may have none, and in some cases IDE programs take over 
+    # Some systems may have none, and in some cases IDE programs take over
     # the assoc.  Detect this so the small number of tests affected can skip.
     try:
         python_assoc = get_template_command('.py')
@@ -564,7 +574,7 @@ if '_JAVA_OPTIONS' in os.environ:
 
 
 # ---[ test discovery ]------------------------------------
-# This section figures which tests to run.
+# This section figures out which tests to run.
 #
 # The initial testlist is made by reading from the testlistfile,
 # if supplied, or by looking at the test arguments, if supplied,
@@ -587,29 +597,38 @@ if '_JAVA_OPTIONS' in os.environ:
 # Test exclusions, if specified, are then applied.
 
 
-def scanlist(testlist):
+def scanlist(testfile):
     """ Process a testlist file """
-    tests = [t.strip() for t in testlist if not t.startswith('#')]
-    return [t for t in tests if t]
+    data = StringIO(testfile.read_text())
+    tests = [t.strip() for t in data.readlines() if not t.startswith('#')]
+    # in order to allow scanned lists to work whether they use forward or
+    # backward slashes, first create the object as a PureWindowsPath which
+    # accepts either, then use that to make a Path object to use for
+    # comparisons like "file in scanned_list".
+    if sys.platform == 'win32':
+        return [Path(t) for t in tests if t]
+    else:
+        return [Path(PureWindowsPath(t).as_posix()) for t in tests if t]
 
 
 def find_unit_tests(directory):
     """ Look for unit tests """
     result = []
-    for dirpath, dirnames, filenames in os.walk(directory):
+    for dirpath, _, filenames in os.walk(directory):
         # Skip folders containing a sconstest.skip file
         if 'sconstest.skip' in filenames:
             continue
         for fname in filenames:
             if fname.endswith("Tests.py"):
-                result.append(os.path.join(dirpath, fname))
+                result.append(Path(dirpath, fname))
+
     return sorted(result)
 
 
 def find_e2e_tests(directory):
     """ Look for end-to-end tests """
     result = []
-    for dirpath, dirnames, filenames in os.walk(directory):
+    for dirpath, _, filenames in os.walk(directory):
         # Skip folders containing a sconstest.skip file
         if 'sconstest.skip' in filenames:
             continue
@@ -617,79 +636,77 @@ def find_e2e_tests(directory):
         # Slurp in any tests in exclude lists
         excludes = []
         if ".exclude_tests" in filenames:
-            p = Path(dirpath).joinpath(".exclude_tests")
-            # TODO simplify when Py3.5 dropped
-            if sys.version_info.major == 3 and sys.version_info.minor < 6:
-                excludefile = p.resolve()
-            else:
-                excludefile = p.resolve(strict=True)
-            with excludefile.open() as f:
-                excludes = scanlist(f)
+            excludefile = Path(dirpath, ".exclude_tests").resolve()
+            excludes = scanlist(excludefile)
 
         for fname in filenames:
-            if fname.endswith(".py") and fname not in excludes:
-                result.append(os.path.join(dirpath, fname))
+            if fname.endswith(".py") and Path(fname) not in excludes:
+                result.append(Path(dirpath, fname))
 
     return sorted(result)
 
 
 # initial selection:
+# if we have a testlist file read that, else hunt for tests.
 unittests = []
 endtests = []
 if args.testlistfile:
-    with args.testlistfile.open() as f:
-        tests = scanlist(f)
+    tests = scanlist(args.testlistfile)
 else:
     testpaths = []
-    if args.all:
-        testpaths = ['SCons', 'test']
-    elif args.testlist:
-        testpaths = args.testlist
+    if args.all:  # -a flag
+        testpaths = [Path('SCons'), Path('test')]
+    elif args.testlist:  # paths given on cmdline
+        if sys.platform == 'win32':
+            testpaths = [Path(t) for t in args.testlist]
+        else:
+            testpaths = [Path(PureWindowsPath(t).as_posix()) for t in args.testlist]
 
-    for tp in testpaths:
-        # Clean up path so it can match startswith's below
-        # remove leading ./ or .\
-        if tp.startswith('.') and tp[1] in (os.sep, os.altsep):
-            tp = tp[2:]
+    for path in testpaths:
+        # Clean up path removing leading ./ or .\
+        name = str(path)
+        if name.startswith('.') and name[1] in (os.sep, os.altsep):
+            path = path.with_name(tn[2:])
 
-        for path in glob.glob(tp):
-            if os.path.isdir(path):
-                if path.startswith(('SCons', 'testing')):
+        if path.exists():
+            if path.is_dir():
+                if path.parts[0] == "SCons" or path.parts[0] == "testing":
                     unittests.extend(find_unit_tests(path))
-                elif path.startswith('test'):
+                elif path.parts[0] == 'test':
                     endtests.extend(find_e2e_tests(path))
+                # else: TODO: what if user pointed to a dir outside scons tree?
             else:
-                if path.endswith("Tests.py"):
+                if path.match("*Tests.py"):
                     unittests.append(path)
-                elif path.endswith(".py"):
+                elif path.match("*.py"):
                     endtests.append(path)
-    tests = sorted(unittests + endtests)
 
+    tests = sorted(unittests + endtests)
 
 # Remove exclusions:
 if args.e2e_only:
-    tests = [t for t in tests if not t.endswith("Tests.py")]
+    tests = [t for t in tests if not t.match("*Tests.py")]
 if args.unit_only:
-    tests = [t for t in tests if t.endswith("Tests.py")]
+    tests = [t for t in tests if t.match("*Tests.py")]
 if args.excludelistfile:
-    with args.excludelistfile.open() as f:
-        excludetests = scanlist(f)
+    excludetests = scanlist(args.excludelistfile)
     tests = [t for t in tests if t not in excludetests]
 
+# did we end up with any tests?
 if not tests:
     sys.stderr.write(parser.format_usage() + """
-error: no tests were found.
-       Tests can be specified on the command line, read from a file with
-       the -f/--file option, or discovered with -a/--all to run all tests.
+error: no tests matching the specification were found.
+       See "Test selection options" in the help for details on
+       how to specify and/or exclude tests.
 """)
     sys.exit(1)
 
 # ---[ test processing ]-----------------------------------
-tests = [Test(t, n + 1) for n, t in enumerate(tests)]
+tests = [Test(t) for t in tests]
 
 if args.list_only:
     for t in tests:
-        sys.stdout.write(t.path + "\n")
+        print(t.path)
     sys.exit(0)
 
 if not args.python:
@@ -702,7 +719,7 @@ os.environ["python_executable"] = args.python
 if args.print_times:
 
     def print_time(fmt, tm):
-        sys.stdout.write(fmt % tm)
+        print(fmt % tm)
 
 else:
 
@@ -739,7 +756,7 @@ def log_result(t, io_lock=None):
                 print(t.stdout)
             if t.stderr:
                 print(t.stderr)
-        print_time("Test execution time: %.1f seconds\n", t.test_time)
+        print_time("Test execution time: %.1f seconds", t.test_time)
     finally:
         if io_lock:
             io_lock.release()
@@ -778,8 +795,8 @@ def run_test(t, io_lock=None, run_async=True):
     if args.printcommand:
         if args.print_progress:
             t.headline += "%d/%d (%.2f%s) %s\n" % (
-                t.num, total_num_tests,
-                float(t.num) * 100.0 / float(total_num_tests),
+                t.testno, total_num_tests,
+                float(t.testno) * 100.0 / float(total_num_tests),
                 "%",
                 t.command_str,
             )
@@ -843,7 +860,7 @@ else:
 # --- all tests are complete by the time we get here ---
 if tests:
     tests[0].total_time = time_func() - total_start_time
-    print_time("Total execution time for all tests: %.1f seconds\n", tests[0].total_time)
+    print_time("Total execution time for all tests: %.1f seconds", tests[0].total_time)
 
 passed = [t for t in tests if t.status == 0]
 fail = [t for t in tests if t.status == 1]
