@@ -1,17 +1,17 @@
+# SPDX-License-Identifier: MIT
+#
+# Copyright The SCons Foundation
+
 import os
 import stat
 import time
-import distutils.util
+import sysconfig
 
+platform = sysconfig.get_platform()
 
-platform = distutils.util.get_platform()
-
-def is_windows():
-    """ Check if we're on a Windows platform"""
-    if platform.startswith('win'):
-        return True
-    else:
-        return False
+def is_windows() -> bool:
+    """Check if we're on a Windows platform"""
+    return platform.startswith('win')
 
 
 def whereis(filename):
@@ -35,9 +35,7 @@ def whereis(filename):
                     return f_ext
     return None
 
+
 # Datestring for debian
 # Should look like: Mon, 03 Nov 2016 13:37:42 -0700
 deb_date = time.strftime("%a, %d %b %Y %H:%M:%S +0000", time.gmtime())
-
-
-
