@@ -1,8 +1,13 @@
+# SPDX-License-Identifier: MIT
+#
+# Copyright The SCons Foundation
+
 import os.path
 import re
 
 from SCons.Script import Builder, Action, Scanner
 
+
 def soelim(target, source, env):
     """
     Interpolate files included in [gnt]roff source files using the
@@ -17,18 +22,19 @@ def soelim(target, source, env):
     t = str(target[0])
     s = str(source[0])
     dir, f = os.path.split(s)
-    with open(t, 'w') as tfp, open(s, 'r') as sfp:
+    with open(t, 'w') as tfp, open(s) as sfp:
         for line in sfp.readlines():
             if line[:4] in ['.so ', "'so "]:
                 sofile = os.path.join(dir, line[4:-1])
-                with open(sofile, 'r') as f:
+                with open(sofile) as f:
                     tfp.write(f.read())
             else:
                 tfp.write(line)
 
+
 def soscan(node, env, path):
     c = node.get_text_contents()
     return re.compile(r"^[.']so\s+(\S+)", re.M).findall(c)
 
-soelimbuilder = Builder(action = Action(soelim),
-                        source_scanner = Scanner(soscan))
+
+soelimbuilder = Builder(action=Action(soelim), source_scanner=Scanner(soscan))
