@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 #
-# __COPYRIGHT__
+# MIT License
+#
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,9 +22,6 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 """
 Verify the ability to set the $AS construction variable to a different
@@ -41,7 +40,9 @@ test.file_fixture('mylink.py')
 test.file_fixture(['fixture', 'myas.py'])
 
 test.write('SConstruct', """
-env = Environment(LINK = r'%(_python_)s mylink.py',
+DefaultEnvironment(tools=[])
+env = Environment(tools=['link','as','gcc'],
+                  LINK = r'%(_python_)s mylink.py',
                   AS = r'%(_python_)s myas.py',
                   CC = r'%(_python_)s myas.py')
 env.Program(target = 'test1', source = 'test1.s')
