@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 #
-# __COPYRIGHT__
+# MIT License
+#
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,9 +22,6 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 import sys
 
@@ -38,14 +37,11 @@ test.file_fixture(['fixture', 'myas_args.py'])
 
 o = ' -x'
 o_c = ' -x -c'
-if sys.platform == 'win32':
-    import SCons.Tool.MSCommon as msc
-
-    if msc.msvc_exists():
-        o_c = ' -x'
 
 test.write('SConstruct', """
-env = Environment(LINK = r'%(_python_)s mylink.py',
+DefaultEnvironment(tools=[])
+env = Environment(tools=['link','as','cc'],
+                  LINK = r'%(_python_)s mylink.py',
                   LINKFLAGS = [],
                   ASPP = r'%(_python_)s myas_args.py', ASPPFLAGS = '-x',
                   CC = r'%(_python_)s myas_args.py')
