@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 #
-# __COPYRIGHT__
+# MIT License
+#
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,7 +22,7 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
+
 """
 Test CompilationDatabase and several variations of ways to call it
 and values of COMPILATIONDB_USE_ABSPATH
@@ -77,7 +79,8 @@ example_rel_file = """[
         "file": "%(src_file)s",
         "output": "%(output2_file)s"
     }
-]""" % {'exe': sys.executable,
+]
+""" % {'exe': sys.executable,
         'workdir': test.workdir,
         'src_file': os.path.join('src', 'test_main.c'),
         'output_file': os.path.join('build', 'test_main.o'),
@@ -106,7 +109,8 @@ example_abs_file = """[
         "file": "%(abs_src_file)s",
         "output": "%(abs_output2_file)s"
     }
-]""" % {'exe': sys.executable,
+]
+""" % {'exe': sys.executable,
         'workdir': test.workdir,
         'src_file': os.path.join('src', 'test_main.c'),
         'abs_src_file': os.path.join(test.workdir, 'src', 'test_main.c'),
@@ -130,7 +134,8 @@ example_filter_build_file = """[
         "file": "%(src_file)s",
         "output": "%(output_file)s"
     }
-]""" % {'exe': sys.executable,
+]
+""" % {'exe': sys.executable,
         'workdir': test.workdir,
         'src_file': os.path.join('src', 'test_main.c'),
         'output_file': os.path.join('build', 'test_main.o'),
@@ -151,7 +156,8 @@ example_filter_build2_file = """[
         "file": "%(src_file)s",
         "output": "%(output2_file)s"
     }
-]""" % {'exe': sys.executable,
+]
+""" % {'exe': sys.executable,
         'workdir': test.workdir,
         'src_file': os.path.join('src', 'test_main.c'),
         'output2_file': os.path.join('build2', 'test_main.o'),
