@@ -40,6 +40,10 @@ test.write('SConstruct', """\
 Execute(Copy('f1.out', 'f1.in'))
 Execute(Copy(File('d2.out'), 'd2.in'))
 Execute(Copy('d3.out', File('f3.in')))
+# Issue #3009: make sure it's not mangled if src is a list.
+# make sure both list-of-str and list-of-Node work
+Execute(Copy('d7.out', ['f10.in', 'f11.in']))
+Execute(Copy('d7.out', Glob('f?.in')))
 
 def cat(env, source, target):
     target = str(target[0])
@@ -71,6 +75,7 @@ test.subdir('d2.in')
 test.write(['d2.in', 'file'], "d2.in/file\n")
 test.write('f3.in', "f3.in\n")
 test.subdir('d3.out')
+test.subdir('d7.out')
 test.write('bar.in', "bar.in\n")
 test.write('f4.in', "f4.in\n")
 test.subdir('d5.in')
@@ -101,6 +106,8 @@ expect = test.wrap_stdout(
 Copy("f1.out", "f1.in")
 Copy("d2.out", "d2.in")
 Copy("d3.out", "f3.in")
+Copy("d7.out", ["f10.in", "f11.in"])
+Copy("d7.out", ["f1.in", "f3.in", "f4.in", "f6.in", "f7.in", "f8.in", "f9.in"])
 """,
     build_str="""\
 cat(["bar.out"], ["bar.in"])
@@ -123,6 +130,8 @@ test.run(options='-n', arguments='.', stdout=expect)
 test.must_not_exist('f1.out')
 test.must_not_exist('d2.out')
 test.must_not_exist(os.path.join('d3.out', 'f3.in'))
+test.must_not_exist(os.path.join('d7.out', 'f7.in'))
+test.must_not_exist(os.path.join('d7.out', 'f11.in'))
 test.must_not_exist('f4.out')
 test.must_not_exist('d5.out')
 test.must_not_exist(os.path.join('d6.out', 'f6.in'))
@@ -141,6 +150,8 @@ test.run()
 test.must_match('f1.out', "f1.in\n", mode='r')
 test.must_match(['d2.out', 'file'], "d2.in/file\n", mode='r')
 test.must_match(['d3.out', 'f3.in'], "f3.in\n", mode='r')
+test.must_match(['d7.out', 'f7.in'], "f7.in\n", mode='r')
+test.must_match(['d7.out', 'f11.in'], "f11.in\n", mode='r')
 test.must_match('f4.out', "f4.in\n", mode='r')
 test.must_match(['d5.out', 'file'], "d5.in/file\n", mode='r')
 test.must_match(['d6.out', 'f6.in'], "f6.in\n", mode='r')
