@@ -75,6 +75,7 @@ test.write(
 """
 import os
 
+DefaultEnvironment(tools=[])
 env = Environment(
     tools = [
         'javac',
@@ -119,5 +120,12 @@ javac -d build -sourcepath org/sample org/sample/Sample.java
 )
 
 test.run( arguments = '--tree=derived', stdout = expected )
-
 test.up_to_date(arguments = '.')
+
+test.pass_test()
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
