@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 #
-# __COPYRIGHT__
+# MIT License
+#
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,9 +22,6 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 """
 Test the PackageVariable canned Variable type.
@@ -39,12 +38,8 @@ def check(expect):
     result = test.stdout().split('\n')
     assert result[1:len(expect)+1] == expect, (result[1:len(expect)+1], expect)
 
-
-
 test.write(SConstruct_path, """\
-from SCons.Variables.PackageVariable import PackageVariable
-PV = PackageVariable
-
+from SCons.Variables.PackageVariable import PackageVariable as PV
 from SCons.Variables import PackageVariable
 
 opts = Variables(args=ARGUMENTS)
@@ -55,7 +50,8 @@ opts.AddVariables(
     PV('package', 'help for package', 'yes'),
     )
 
-env = Environment(variables=opts)
+_ = DefaultEnvironment(tools=[])
+env = Environment(variables=opts, tools=[])
 Help(opts.GenerateHelpText(env))
 
 print(env['x11'])
@@ -74,14 +70,17 @@ check([str(False)])
 test.run(arguments=['x11=%s' % test.workpath()])
 check([test.workpath()])
 
+space_subdir = test.workpath('space subdir')
+test.subdir(space_subdir)
+test.run(arguments=[f'x11={space_subdir}'])
+check([space_subdir])
+
 expect_stderr = """
-scons: *** Path does not exist for option x11: /non/existing/path/
-""" + test.python_file_line(SConstruct_path, 14)
+scons: *** Path does not exist for variable 'x11': '/non/existing/path/'
+""" + test.python_file_line(SConstruct_path, 13)
 
 test.run(arguments='x11=/non/existing/path/', stderr=expect_stderr, status=2)
 
-
-
 test.pass_test()
 
 # Local Variables:
