@@ -40,6 +40,7 @@ import sys
 
 from TestCommon import *
 from TestCommon import __all__
+from TestCmd import IS_WINDOWS
 # some of the scons_time tests may need regex-based matching:
 from TestSCons import search_re, search_re_in_list
 
@@ -73,8 +74,7 @@ with open('SConstruct', 'r') as f:
 exec(script)
 """
 
-svn_py = """\
-#!/usr/bin/env python
+svn_py = f"""#!/usr/bin/env python
 import os
 import sys
 
@@ -82,12 +82,11 @@ dir = sys.argv[-1]
 script_dir = dir + '/scripts'
 os.makedirs(script_dir)
 with open(script_dir + '/scons.py', 'w') as f:
-    f.write(r'''%s''')
-""" % scons_py
+    f.write(r'''{scons_py}''')
+"""
 
 
-git_py = """\
-#!/usr/bin/env python
+git_py = f"""#!/usr/bin/env python
 import os
 import sys
 
@@ -95,8 +94,8 @@ dir = sys.argv[-1]
 script_dir = dir + '/scripts'
 os.makedirs(script_dir)
 with open(script_dir + '/scons.py', 'w') as f:
-    f.write(r'''%s''')
-""" % scons_py
+    f.write(r'''{scons_py}''')
+"""
 
 
 logfile_contents = """\
@@ -105,7 +104,7 @@ Memory after reading SConscript files:  200%(index)s
 Memory before building targets:  300%(index)s
 Memory after building targets:  400%(index)s
 Object counts:
-       pre-   post-    pre-   post-   
+       pre-   post-    pre-   post-
        read    read   build   build   Class
        101%(index)s    102%(index)s    103%(index)s    104%(index)s   Action.CommandAction
        201%(index)s    202%(index)s    203%(index)s    204%(index)s   Action.CommandGeneratorAction
@@ -157,7 +156,7 @@ class TestSCons_time(TestCommon):
     initializations.
     """
 
-    def __init__(self, **kw):
+    def __init__(self, **kw) -> None:
         """Initialize an SCons_time testing object.
 
         If they're not overridden by keyword arguments, this
@@ -207,10 +206,10 @@ class TestSCons_time(TestCommon):
         else:
             return os.path.splitext(path)
 
-    def fake_logfile(self, logfile_name, index=0):
+    def fake_logfile(self, logfile_name, index: int=0) -> None:
         self.write(self.workpath(logfile_name), logfile_contents % locals())
 
-    def profile_data(self, profile_name, python_name, call, body):
+    def profile_data(self, profile_name, python_name, call, body) -> None:
         profile_name = self.workpath(profile_name)
         python_name = self.workpath(python_name)
         d = {
@@ -238,15 +237,19 @@ class TestSCons_time(TestCommon):
         except AttributeError:
             pass
         else:
-            tempdir = realpath(tempdir)
+            # Don't realpath on Windows, tempdir could contain 8+3 path
+            # E.g. username on GitHub runner is "runneradmin" -> "RUNNER~1"
+            # We don't want to convert that back!
+            if not IS_WINDOWS:
+                tempdir = realpath(tempdir)
 
         args = (tempdir, 'scons-time-',) + args
         x = os.path.join(*args)
         x = re.escape(x)
-        x = x.replace('time\\-', 'time\\-[^%s]*' % sep)
+        x = x.replace('time\\-', f'time\\-[^{sep}]*')
         return x
 
-    def write_fake_scons_py(self):
+    def write_fake_scons_py(self) -> None:
         self.subdir('scripts')
         self.write('scripts/scons.py', scons_py)
 
@@ -275,20 +278,16 @@ class TestSCons_time(TestCommon):
 
     def write_sample_tarfile(self, archive, dir, files):
         import shutil
-        try:
-            import tarfile
-        except ImportError:
-            self.skip_test('no tarfile module\n', from_framework=True)
-        else:
-            base, suffix = self.archive_split(archive)
+        import tarfile
+        base, suffix = self.archive_split(archive)
 
-            mode = {
-                '.tar'      : 'w',
-                '.tar.gz'   : 'w:gz',
-                '.tgz'      : 'w:gz',
-            }
+        mode = {
+            '.tar'      : 'w',
+            '.tar.gz'   : 'w:gz',
+            '.tgz'      : 'w:gz',
+        }
 
-            tar = tarfile.open(archive, mode[suffix])
+        with tarfile.open(archive, mode[suffix]) as tar:
             for name, content in files:
                 path = os.path.join(dir, name)
                 with open(path, 'wb') as f:
@@ -300,30 +299,20 @@ class TestSCons_time(TestCommon):
                 tarinfo.gname = 'fake_group'
                 with open(path, 'rb') as f:
                     tar.addfile(tarinfo, f)
-            tar.close()
-            shutil.rmtree(dir)
-            return self.workpath(archive)
+        shutil.rmtree(dir)
+        return self.workpath(archive)
 
     def write_sample_zipfile(self, archive, dir, files):
         import shutil
-        try:
-            import zipfile
-        except ImportError:
-
-            sys.stderr.write('no zipfile module\n')
-            self.no_result()
-
-        else:
-
-            zip = zipfile.ZipFile(archive, 'w')
+        import zipfile
+        with zipfile.ZipFile(archive, 'w') as zip:
             for name, content in files:
                 path = os.path.join(dir, name)
                 with open(path, 'w') as f:
                     f.write(content)
                 zip.write(path)
-            zip.close()
-            shutil.rmtree(dir)
-            return self.workpath(archive)
+        shutil.rmtree(dir)
+        return self.workpath(archive)
 
     sample_project_files = [
         ('SConstruct',  SConstruct),
